Module: Capybara::DSL
- Defined in:
- lib/capybara-screenshot/capybara.rb
Instance Method Summary collapse
- #screenshot_and_open_image(filename_prefix: nil) ⇒ Object
-
#screenshot_and_save_page(filename_prefix: nil, save_html: true) ⇒ Object
Adds class methods to Capybara module and gets mixed into the current scope during Cucumber and RSpec tests.
Instance Method Details
#screenshot_and_open_image(filename_prefix: nil) ⇒ Object
26 27 28 |
# File 'lib/capybara-screenshot/capybara.rb', line 26 def screenshot_and_open_image(filename_prefix: nil) Capybara::Screenshot.screenshot_and_open_image(filename_prefix: filename_prefix) end |
#screenshot_and_save_page(filename_prefix: nil, save_html: true) ⇒ Object
Adds class methods to Capybara module and gets mixed into the current scope during Cucumber and RSpec tests
22 23 24 |
# File 'lib/capybara-screenshot/capybara.rb', line 22 def screenshot_and_save_page(filename_prefix: nil, save_html: true) Capybara::Screenshot.screenshot_and_save_page(filename_prefix: filename_prefix, save_html: save_html) end |